from boto3 import client
from json import loads

__REGION__ = 'us-east-1'


def set_region(region):
    global __REGION__

    __REGION__ = region


def get_secret(secret_name, region=__REGION__):
    # This function gets the value of a secret, i.e. the entire secret value.
    ssm = client('secretsmanager', region_name=region)
    secret_string = ssm.get_secret_value(SecretId=secret_name)['SecretString']
    return secret_string


def get_secret_value(secret_name, secret_key, region=__REGION__):
    # This function gets a value from a specific key-value pair within a secret stored as a valid json string.
    ssm = client('secretsmanager', region_name=region)
    secret_string = loads(ssm.get_secret_value(SecretId=secret_name)['SecretString'])
    return secret_string.get(secret_key, None)


if __name__ == '__main__':
    # for testing
    sv = get_secret('prod/astro/workspace/api_key/recast_programmatic')
    print(sv)
    sv = get_secret_value('prod/astro/workspace/api_key/recast_programmatic', 'api_key')
    print(sv)
