import json
from RecastPy.aws.secrets_manager import get_secret
from slack_sdk import WebClient

__REGION__ = 'us-east-1'
__TOKEN__ = None


def set_region(region):
    global __REGION__

    __REGION__ = region


def set_token(token=None):
    global __TOKEN__, __REGION__

    if token:
        __TOKEN__ = token
    else:
        __TOKEN__ = get_secret(secret_name='prod/slack/token/recast-alert-bot', region=__REGION__)


def get_token():
    global __TOKEN__, __REGION__

    if __TOKEN__:
        return __TOKEN__
    else:
        return get_secret(secret_name='prod/slack/token/recast-alert-bot', region=__REGION__)


def post_message(channel: str, message: str = None, blocks: list = None, icon_emoji: str = None):
    slack = WebClient(token=get_token())

    slack.chat_postMessage(channel=channel, text=message, blocks=json.dumps(blocks), icon_emoji=icon_emoji)


if __name__ == '__main__':
    # for testing
    blocks = [
            {
                "type": "header",
                "text": {
                    "type": "plain_text",
                    "text": ":rotating_light: Run Failure :rotating_light:",
                    "emoji": True
                }
            },
            {
                "type": "divider"
            },
            {
                "type": "section",
                "fields": [
                    {
                        "type": "mrkdwn",
                        "text": "*DAG:*\nrun_all_fleets"
                    },
                    {
                        "type": "mrkdwn",
                        "text": "*Execution Time:*\n2022-03-31T20:28:39+00:00"
                    }
                ]
            },
            {
                "type": "section",
                "fields": [
                    {
                        "type": "mrkdwn",
                        "text": "*Task:*\nmonitor_batch_jobs"
                    },
                    {
                        "type": "mrkdwn",
                        "text": "*Fleets:*\ntest_fleet_of_0, test_fleet_of_0_no_stacking"
                    }
                ]
            },
            {
                "type": "divider"
            },
            {
                "type": "actions",
                "elements": [
                    {
                        "type": "button",
                        "text": {
                            "type": "plain_text",
                            "emoji": True,
                            "text": "OpMan ⧉"
                        },
                        "style": "primary",
                        "url": "https://beta-page-recast.vercel.app/"
                    }
                ]
            }
        ]

    post_message(channel='slack-test', blocks=blocks, icon_emoji=":robot_face:")
